@@ -1,6 +1,9 @@
+import gzip
 from collections import OrderedDict, Hashable
 from typing import Union, Dict, Any
 
+from mysutils.tar import open_tar_file
+
 try:
     from yaml import add_representer, dump, load, SafeLoader
 except ModuleNotFoundError as e:
@@ -28,3 +31,16 @@ def load_yaml(fname: str) -> Union[Dict[Hashable, Any], list, None]:
     """
     with open_file(fname, 'rt') as file:
         return load(file, SafeLoader)
+
+
+def load_tar_yaml(tar_file: str, filename: str) -> Any:
+    """ Load an object from a YAML file stored in a tar file.
+
+    :param tar_file: The path to the tar file-.
+    :param filename: The path inside of the tar to the file to extract.
+    :return: The loaded object.
+    """
+    with open_tar_file(tar_file, filename) as file:
+        if filename.lower().endswith('.gz'):
+            return load(gzip.open(file))
+        return load(file)
